﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Drawing;
using System.Xml;

namespace EduNetworkBuilder
{
    /// <summary>
    /// For drawing shapes on a network.  Rectangles, circles.  Filled or not
    /// </summary>
    public class NetShape
    {
        public NetShapeType MyShape = NetShapeType.none;
        public Rectangle InArea;
        public Color WhatColor = Color.Empty;

        public NetShape(NetShapeType What, Rectangle Where, Color color)
        {
            MyShape = What;
            InArea = Where;
            WhatColor = color;
        }
        public NetShape(XmlNode what)
        {
            Load(what);
        }

        /// <summary>
        /// Draw the specified shape on the image
        /// </summary>
        /// <param name="baseImage"></param>
        public void Draw(Image baseImage)
        {
            Graphics G = Graphics.FromImage(baseImage);
            Pen coloredPen = new Pen(WhatColor);
            Brush coloredBrush = new SolidBrush(WhatColor);
            switch(MyShape)
            {
                case NetShapeType.circle:
                    G.DrawEllipse(coloredPen, InArea);
                    break;
                case NetShapeType.filled_circle:
                    G.FillEllipse(coloredBrush,InArea);
                    break;
                case NetShapeType.rectangle:
                    G.DrawRectangle(coloredPen, InArea);
                    break;
                case NetShapeType.filled_rectangle:
                    G.FillRectangle(coloredBrush, InArea);
                    break;
            }
            G.Dispose();
        }

        public void Load(XmlNode theNode)
        {
            foreach (XmlNode Individual in theNode.ChildNodes)
            {
                XmlNodeType myNodetype = Individual.NodeType;
                if (myNodetype == XmlNodeType.Element)
                {
                    switch (Individual.Name.ToLower())
                    {
                        case "what":
                            MyShape = NB.TryParseEnum<NetShapeType>(Individual.InnerText, NetShapeType.none);
                            break;
                        case "where":
                            RectangleConverter converter = new RectangleConverter();
                            InArea = (Rectangle)converter.ConvertFromString(Individual.InnerText);
                            break;
                        case "color":
                            WhatColor = Color.FromName(Individual.InnerText);
                            break;
                    }
                }
            }
        }

        public void Save(XmlWriter writer)
        {
            writer.WriteStartElement("shape");
            writer.WriteElementString("what", MyShape.ToString());
            RectangleConverter converter = new RectangleConverter();
            writer.WriteElementString("where", converter.ConvertToString(InArea));
            writer.WriteElementString("color", WhatColor.Name);
            writer.WriteEndElement();
        }
    }
}
